@@ -114,16 +114,16 @@ def crosssection_vt_fho(g: float, T: float, idata: np.ndarray, molecule: Molecul
         if model == 'GSS':
             return (constants.physical_constants['Angstrom star'][0] ** 2) *\
                    raw_crosssection_vt_gss_fho(g, T, idata[0], idata[4], idata[16], idata[17], idata[18], idata[19],
-                                               molecule.vibr[i], molecule.vibr[i + delta], molecule.vibr_zero,
+                                               molecule.vibr[i], molecule.vibr[i + delta],
                                                molecule.diss, i, delta)
         elif model == 'VSS':
             return (constants.physical_constants['Angstrom star'][0] ** 2) *\
                    raw_crosssection_vt_vss_fho(g, T, idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
-                                               molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                               molecule.vibr[i + delta], molecule.diss,
                                                i, delta)
         else:
             return raw_crosssection_vt_rigid_sphere_fho(g, T, idata[0], idata[0], idata[4], molecule.vibr[i],
-                                                        molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                                        molecule.vibr[i + delta], molecule.diss,
                                                         i, delta)
     else:
         raise KineticlibError('VT transition with no change in vibrational level specified')
@@ -323,14 +323,14 @@ def vt_integral_fho(T: float, deg: int, idata: np.ndarray, molecule: Molecule, i
     """
     if model == 'GSS':
         return raw_vt_integral_gss_fho(T, deg, idata[0], idata[4], idata[16], idata[17], idata[18], idata[19],
-                                       molecule.vibr[i], molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                       molecule.vibr[i], molecule.vibr[i + delta], molecule.diss,
                                        i, delta, nokt)
     elif model == 'VSS':
         return raw_vt_integral_vss_fho(T, deg, idata[0], idata[4], idata[9], idata[10], molecule.vibr[i],
-                                       molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss, i, delta, nokt)
+                                       molecule.vibr[i + delta], molecule.diss, i, delta, nokt)
     else:
         return raw_vt_integral_rigid_sphere_fho(T, deg, idata[1], idata[0], idata[4], molecule.vibr[i],
-                                                molecule.vibr[i + delta], molecule.vibr_zero, molecule.diss,
+                                                molecule.vibr[i + delta], molecule.diss,
                                                 i, delta, nokt)
 
 
@@ -947,7 +947,7 @@ def raw_elastic_collision_time(T: float, mass: float, vssc: float, vsso: float,
 
 def raw_crosssection_vt_gss_fho(g: float, T: float, mass: float, beta: float, gssc1: float, gssc2: float,
                                 gsso1: float, gsso2: float,
-                                ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float,
+                                ve_before: float, ve_after: float, molecule_diss: float,
                                 i: int, delta: int) -> float:
     """Calculates the VT crosssection (in square Angstroms) using the FHO probability and GSS model
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
@@ -974,8 +974,6 @@ def raw_crosssection_vt_gss_fho(g: float, T: float, mass: float, beta: float, gs
         the vibrational energy of the molecule before the transition
     ve_after : float
         the vibrational energy of the molecule after the transition
-    molecule_vibr_zero : float
-        the energy of the 0-th vibrational level
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -988,12 +986,12 @@ def raw_crosssection_vt_gss_fho(g: float, T: float, mass: float, beta: float, gs
     float
         The VT crosssection
     """
-    return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+    return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_diss, i, delta)\
            * raw_crosssection_elastic_gss(g, T, gssc1, gssc2, gsso1, gsso2)
 
 
 def raw_crosssection_vt_vss_fho(g: float, T: float, mass: float, beta: float, vssc: float, vsso: float,
-                                ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float,
+                                ve_before: float, ve_after: float, molecule_diss: float,
                                 i: int, delta: int) -> float:
     """Calculates the VT crosssection (in square Angstroms) using the FHO probability and VSS model
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
@@ -1016,8 +1014,6 @@ def raw_crosssection_vt_vss_fho(g: float, T: float, mass: float, beta: float, vs
         the vibrational energy of the molecule before the transition
     ve_after : float
         the vibrational energy of the molecule after the transition
-    molecule_vibr_zero : float
-        the energy of the 0-th vibrational level
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -1030,12 +1026,12 @@ def raw_crosssection_vt_vss_fho(g: float, T: float, mass: float, beta: float, vs
     float
         The VT crosssection
     """
-    return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+    return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_diss, i, delta)\
            * raw_crosssection_elastic_vss(g, T, vssc, vsso)
 
 
 def raw_crosssection_vt_rigid_sphere_fho(g: float, T: float, sigma: float, mass: float, beta: float,
-                                         ve_before: float, ve_after: float, molecule_vibr_zero: float,
+                                         ve_before: float, ve_after: float,
                                          molecule_diss: float, i: int, delta: int) -> float:
     """Calculates the VT crosssection using the FHO probability and rigid sphere model
     for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
@@ -1056,8 +1052,6 @@ def raw_crosssection_vt_rigid_sphere_fho(g: float, T: float, sigma: float, mass:
         the vibrational energy of the molecule before the transition
     ve_after : float
         the vibrational energy of the molecule after the transition
-    molecule_vibr_zero : float
-        the energy of the 0-th vibrational level
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -1070,7 +1064,7 @@ def raw_crosssection_vt_rigid_sphere_fho(g: float, T: float, sigma: float, mass:
     float
         The VT crosssection
     """
-    return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_vibr_zero, molecule_diss, i, delta)\
+    return prob.vt_probability_fho(g, T, mass, beta, ve_before, ve_after, molecule_diss, i, delta)\
            * raw_crosssection_elastic_rigid_sphere(sigma)
 
 
@@ -1439,7 +1433,7 @@ def elastic_omega_g_only_rigid_sphere(g: float, deg: int) -> float:
 
 
 def raw_vt_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1: float, gssc2: float,
-                            gsso1: float, gsso2: float, ve_before: float, ve_after: float, molecule_vibr_zero: float,
+                            gsso1: float, gsso2: float, ve_before: float, ve_after: float,
                             molecule_diss: float, i: int,
                             delta: int, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and GSS
@@ -1467,8 +1461,6 @@ def raw_vt_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1:
         the vibrational energy of the molecule before the transition
     ve_after : float
         the vibrational energy of the molecule after the transition
-    molecule_vibr_zero : float
-        the energy of the 0-th vibrational level (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -1490,7 +1482,6 @@ def raw_vt_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1:
 
     """
     if delta != 0:
-        molecule_depth = molecule_vibr_zero + molecule_diss
         if delta == 1:
             mult = (i + 1)
         elif delta == -1:
@@ -1508,10 +1499,10 @@ def raw_vt_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1:
                     * ((0.5 / (constants.pi * mass)) ** 0.5)
         svt = prob.svt(delta)
         f1 = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
-                                               i, delta, molecule_depth, svt)\
+                                               i, delta, molecule_diss, svt)\
                     * elastic_omega_g_only_vss(g, deg, -gsso1)
         f2 = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
-                                               i, delta, molecule_depth, svt)\
+                                               i, delta, molecule_diss, svt)\
                     * elastic_omega_g_only_vss(g, deg, -gsso2)
         return mult * (gssc1 * ((constants.k * T) ** gsso1) * integrate.quad(f1, 0, np.inf)[0] +
                        gssc2 * ((constants.k * T) ** gsso2) * integrate.quad(f2, 0, np.inf)[0])
@@ -1520,7 +1511,7 @@ def raw_vt_integral_gss_fho(T: float, deg: int, mass: float, beta: float, gssc1:
 
 
 def raw_vt_integral_vss_fho(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
-                            ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float, i: int,
+                            ve_before: float, ve_after: float, molecule_diss: float, i: int,
                             delta: int, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and VSS
     cross-section model for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
@@ -1543,8 +1534,6 @@ def raw_vt_integral_vss_fho(T: float, deg: int, mass: float, beta: float, vssc:
         the vibrational energy of the molecule before the transition
     ve_after : float
         the vibrational energy of the molecule after the transition
-    molecule_vibr_zero : float
-        the energy of the 0-th vibrational level (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -1566,7 +1555,6 @@ def raw_vt_integral_vss_fho(T: float, deg: int, mass: float, beta: float, vssc:
 
     """
     if delta != 0:
-        molecule_depth = molecule_vibr_zero + molecule_diss
         if delta == 1:
             mult = (i + 1)
         elif delta == -1:
@@ -1585,7 +1573,7 @@ def raw_vt_integral_vss_fho(T: float, deg: int, mass: float, beta: float, vssc:
 
         svt = prob.svt(delta)
         f = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
-                                              i, delta, molecule_depth, svt)\
+                                              i, delta, molecule_diss, svt)\
                     * elastic_omega_g_only_vss(g, deg, vsso)
         return mult * vssc * (T ** (-vsso)) * integrate.quad(f, 0, np.inf)[0]
     else:
@@ -1593,7 +1581,7 @@ def raw_vt_integral_vss_fho(T: float, deg: int, mass: float, beta: float, vssc:
 
 
 def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: float, beta: float,
-                                    ve_before: float, ve_after: float, molecule_vibr_zero: float, molecule_diss: float,
+                                    ve_before: float, ve_after: float, molecule_diss: float,
                                     i: int, delta: int, nokt: bool=False) -> float:
     """Calculates the generalized VT omega integral using the FHO probability and rigid sphere
     cross-section model for the following process: **M(i) + P -> M(i + delta) + P**, *raw* version
@@ -1614,8 +1602,6 @@ def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
         the vibrational energy of the molecule before the transition
     ve_after : float
         the vibrational energy of the molecule after the transition
-    molecule_vibr_zero : float
-        the energy of the 0-th vibrational level (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which undergoes the transition (with no offset)
     i : int
@@ -1637,7 +1623,6 @@ def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
 
     """
     if delta != 0:
-        molecule_depth = molecule_vibr_zero + molecule_diss
         if delta == 1:
             mult = (i + 1)
         elif delta == -1:
@@ -1654,7 +1639,7 @@ def raw_vt_integral_rigid_sphere_fho(T: float, deg: int, sigma: float, mass: flo
 
         svt = prob.svt(delta)
         f = lambda g: prob.vt_prob_g_only_fho(g, T, mass, beta, ve_before, ve_after,
-                                              i, delta, molecule_depth, svt)\
+                                              i, delta, molecule_diss, svt)\
                     * elastic_omega_g_only_rigid_sphere(g, deg)
         return mult * (sigma ** 2) * integrate.quad(f, 0, np.inf)[0]
     else:
