@@ -8,7 +8,7 @@ __status__ = "Production"
 
 import numpy as np
 from scipy import constants
-from .crosssection import raw_diss_integral
+from .crosssection import diss_integral
 from .particles import Molecule, MoleculeMultiT, Atom, MoleculeQuasi
 from math import exp
 
@@ -97,6 +97,7 @@ def diss_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, i: i
         
             * 'RS' (Rigid Sphere model)
             * 'VSS' (Variable Soft Sphere model)
+            * 'GSS' (Generalized Soft Sphere model)
 
         defaults to 'VSS'
 
@@ -105,17 +106,7 @@ def diss_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, i: i
     float
         Non-equilibrium dissociation state-to-state rate constant
     """
-    if model == 'VSS':
-        pass
-    else:
-        if isinstance(molecule, MoleculeMultiT):
-            return raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                              molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
-                                              center_of_mass, vl_dependent, model)
-        else:
-            return raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                              molecule.vibr[i], molecule.diss,
-                                              center_of_mass, vl_dependent, model)
+    return 8. * diss_integral(T, 0, idata, molecule, i, center_of_mass, vl_dependent, model, False)
 
 
 def rec_rate_treanor_marrone_sts(T: float, model_data: np.ndarray, molecule: Molecule, atom1: Atom, atom2: Atom,
@@ -194,6 +185,7 @@ def rec_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1
         
             * 'RS' (Rigid Sphere model)
             * 'VSS' (Variable Soft Sphere model)
+            * 'GSS' (Generalized Soft Sphere model)
 
         defaults to 'VSS'
 
@@ -202,19 +194,13 @@ def rec_rate_integral_sts(T: float, idata: np.ndarray, molecule: Molecule, atom1
     float
         Recombination state-to-state rate constant
     """
-    if model == 'VSS':
-        pass
+    if isinstance(molecule, MoleculeMultiT):
+        mult = rec_rate_sts_multiplier(T, molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                       atom2.mass, molecule.vibr[i] + molecule.vibr_zero, molecule.diss)
     else:
-        if isinstance(molecule, MoleculeMultiT):
-            return raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                             molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                             atom2.mass, molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
-                                             center_of_mass, vl_dependent, model)
-        else:
-            return raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                             molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                             atom2.mass, molecule.vibr[i], molecule.diss,
-                                             center_of_mass, vl_dependent, model)
+        mult = rec_rate_sts_multiplier(T, molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                       atom2.mass, molecule.vibr[i], molecule.diss)
+    return 8.0 * mult * diss_integral(T, 0, idata, molecule, i, center_of_mass, vl_dependent, model, False)
 
 
 def diss_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
@@ -291,6 +277,7 @@ def diss_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecul
         
             * 'RS' (Rigid Sphere model)
             * 'VSS' (Variable Soft Sphere model)
+            * 'GSS' (Generalized Soft Sphere model)
 
         defaults to 'VSS'
         
@@ -300,23 +287,16 @@ def diss_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecul
         Non-equilibrium dissociation rate constant
     """
     res = 0.0
-    if model == 'VSS':
-        pass
+    if isinstance(molecule, MoleculeMultiT):
+        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+            res += molecule.vibr_exp(T, T1, i) \
+                   * diss_integral(T, 0, idata, molecule, i, center_of_mass, vl_dependent, model, False)
+        return 8.0 * res / molecule.Z_vibr(T, T1)
     else:
-        if isinstance(molecule, MoleculeMultiT):
-            for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-                res += molecule.vibr_exp(T, T1, i) \
-                       * raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                                    molecule.vibr[i] + molecule.vibr_zero, molecule.diss,
-                                                    center_of_mass, vl_dependent, model)
-            return res / molecule.Z_vibr(T, T1)
-        else:
-            for i in range(molecule.num_vibr + 1):
-                res += molecule.vibr_exp(T, i) \
-                       * raw_diss_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                                    molecule.vibr[i], molecule.diss,
-                                                    center_of_mass, vl_dependent, model)
-            return res / molecule.Z_vibr(T)
+        for i in range(molecule.num_vibr + 1):
+            res += molecule.vibr_exp(T, i) \
+                   * diss_integral(T, 0, idata, molecule, i, center_of_mass, vl_dependent, model, False)
+        return 8.0 * res / molecule.Z_vibr(T)
 
 
 def rec_rate_treanor_marrone(T: float, T1: float, model_data: np.ndarray, molecule: MoleculeQuasi,
@@ -403,6 +383,7 @@ def rec_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecule
         
             * 'RS' (Rigid Sphere model)
             * 'VSS' (Variable Soft Sphere model)
+            * 'GSS' (Generalized Soft Sphere model)
 
         defaults to 'VSS'
 
@@ -412,22 +393,17 @@ def rec_rate_integral(T: float, T1: float, idata: np.ndarray, molecule: Molecule
         Averaged recombination rate constant
     """
     res = 0.0
-    if model == 'VSS':
-        pass
+    if isinstance(molecule, MoleculeMultiT):
+        for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
+            res += rec_rate_sts_multiplier(T, molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                           atom2.mass, molecule.vibr[i] + molecule.vibr_zero, molecule.diss)\
+                   * diss_integral(T, 0, idata, molecule, i, center_of_mass, vl_dependent, model, False)
     else:
-        if isinstance(molecule, MoleculeMultiT):
-            for i in range(molecule.num_vibr_levels(T, T1, True) + 1):
-                res += raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                                 molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                                 atom2.mass, molecule.vibr[i] + molecule.vibr_zero,
-                                                 molecule.diss, center_of_mass, vl_dependent, model)
-        else:
-            for i in range(molecule.num_vibr + 1):
-                res += raw_rec_rate_integral_sts(T, idata[1], idata[0], idata[9], idata[10],
-                                                 molecule.Z_rot(T), molecule.mass, atom1.mass,
-                                                 atom2.mass, molecule.vibr[i], molecule.diss,
-                                                 center_of_mass, vl_dependent, model)
-        return res
+        for i in range(molecule.num_vibr + 1):
+            res += rec_rate_sts_multiplier(T, molecule.Z_rot(T), molecule.mass, atom1.mass,
+                                           atom2.mass, molecule.vibr[i], molecule.diss)\
+                   * diss_integral(T, 0, idata, molecule, i, center_of_mass, vl_dependent, model, False)
+    return 8.0 * res
 
 
 def raw_k_diss_eq(T: float, arrhenius_n: float, arrhenius_A: float, molecule_diss: float) -> float:
@@ -480,53 +456,6 @@ def raw_diss_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
     return Z_diss * raw_k_diss_eq(T, arrhenius_n, arrhenius_A, molecule_diss)
 
 
-def raw_diss_rate_integral_sts(T: float, sigma: float, mass: float, vssc: float, vsso: float,
-                               molecule_vibr: float, molecule_diss: float,
-                               center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
-    """Calculates the state-to-state non-equilibrium dissociation rate constant using the generalized
-    omega integral over the VSS or rigid sphere crosssection, *raw* version
-
-    Parameters
-    ----------
-    T : float
-        the temperature of the mixture
-    sigma : float
-        the collision diameter :math:`\\sigma_{cd}`
-    mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    vssc : float
-        the elastic crosssection VSS potential :math:`C` parameter
-    vsso : float
-        the elastic crosssection VSS potential :math:`\\omega` parameter
-    molecule_vibr : float
-        the dimensional vibrational energy of the level from which the molecule dissociates (if ``vl_dependent``
-        is ``False``, can be any value) (with no offset)
-    molecule_diss : float
-        the dissociation energy of the molecule which dissociates (with no offset)
-    center_of_mass : bool, optional
-        if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
-        if ``False``, the total kinetic energy will be used, defaults to ``True``
-    vl_dependent : bool, optional
-        if ``True``, the dissociation crosssection takes into account the vibrational energy of the
-        dissociating molecule,
-        if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
-    model : str, optional
-        the elastic crosssection model to be used, possible values:
-
-            * 'RS' (Rigid Sphere model)
-            * 'VSS' (Variable Soft Sphere model)
-
-        defaults to 'VSS'
-
-    Returns
-    -------
-    float
-        Non-equilibrium dissociation rate constant
-    """
-    return 8.0 * raw_diss_integral(T, 0, sigma, mass, vssc, vsso, molecule_vibr, molecule_diss, center_of_mass,
-                                   vl_dependent, model, False)
-
-
 def raw_rec_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A: float,
                                      Z_diss: float, Z_rot: float, mass_molecule: float, mass_atom1: float,
                                      mass_atom2: float, molecule_vibr: float, molecule_diss: float) -> float:
@@ -568,25 +497,15 @@ def raw_rec_rate_treanor_marrone_sts(T: float, arrhenius_n: float, arrhenius_A:
            * raw_diss_rate_treanor_marrone_sts(T, arrhenius_n, arrhenius_A, Z_diss, molecule_diss)
 
 
-def raw_rec_rate_integral_sts(T: float, sigma: float, mass: float, vssc: float, vsso: float,
-                              Z_rot: float, mass_molecule: float, mass_atom1: float, mass_atom2: float,
-                              molecule_vibr: float, molecule_diss: float,
-                              center_of_mass: bool=True, vl_dependent: bool=True, model: str='VSS') -> float:
-    """Calculates the state-to-state recombination rate constant using the generalized
-    omega integral over the VSS or rigid sphere crosssection, *raw* version
+def rec_rate_sts_multiplier(T: float, Z_rot: float, mass_molecule: float, mass_atom1: float, mass_atom2: float,
+                            molecule_vibr: float, molecule_diss: float):
+    """Calculates the state-to-state recombination rate constant divided by the corresponding
+    dissociation rate constant
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
-    sigma : float
-        the collision diameter :math:`\\sigma_{cd}`
-    mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    vssc : float
-        the elastic crosssection VSS potential :math:`C` parameter
-    vsso : float
-        the elastic crosssection VSS potential :math:`\\omega` parameter
     Z_rot : float
         the value of the rotational partition function of the molecule which dissociates
     mass_molecule : float
@@ -600,28 +519,12 @@ def raw_rec_rate_integral_sts(T: float, sigma: float, mass: float, vssc: float,
         is ``False``, can be any value) (with no offset)
     molecule_diss : float
         the dissociation energy of the molecule which dissociates (with no offset)
-    center_of_mass : bool, optional
-        if ``True``, the kinetic energy of the collision partners will be calculated along the center-of-mass line,
-        if ``False``, the total kinetic energy will be used, defaults to ``True``
-    vl_dependent : bool, optional
-        if ``True``, the dissociation crosssection takes into account the vibrational energy of the
-        dissociating molecule,
-        if ``False``, the crosssection is independent of the vibrational energy, defaults to ``True``
-    model : str, optional
-        the elastic crosssection model to be used, possible values:
-
-            * 'RS' (Rigid Sphere model)
-            * 'VSS' (Variable Soft Sphere model)
-
-        defaults to 'VSS'
 
     Returns
     -------
     float
-        Recombination rate constant
+        Recombination rate constant divided by the corresponding dissociation rate constant
     """
     return Z_rot * (constants.h ** 3) * ((mass_molecule / (2.0 * mass_atom1
                                                            * mass_atom2 * constants.pi * constants.k * T)) ** 1.5)\
-           * exp(-(molecule_diss - molecule_vibr) / (constants.k * T))\
-           * raw_diss_rate_integral_sts(T, sigma, mass, vssc, vsso, molecule_vibr, molecule_diss,
-                                        center_of_mass, vl_dependent, model)
+           * exp(-(molecule_diss - molecule_vibr) / (constants.k * T))
